.. _image-plotting:

.. currentmodule:: gammapy.maps

Image plotting
==============

`gammapy.maps` provides a few helper functions and classes to create
publication-quality images.

Colormaps
---------

The following example shows how to plot images using colormaps that are commonly
used in gamma-ray astronomy (`colormap_hess` and `colormap_milagro`).

.. plot:: maps/colormap_example.py
